@@ -73,19 +73,22 @@ class appMod(base):
                                 )
         return self.get_last_one_mod_id()
 
+    def delete(self, module_id):
+        data = {
+            "moduleId": module_id,
+        }
+        response = self.request(api_name="appModdel.jhtml",
+                                data=data,
+                                method="POST"
+                                )
+        data["response"] = response
+        logger.debug(data)
+
     def delete_all(self):
         rows = self.list()
         for row in rows:
             module_id = row.get("appModuleId")
-            data = {
-                "moduleId": module_id,
-            }
-            response = self.request(api_name="appModdel.jhtml",
-                                    data=data,
-                                    method="POST"
-                                    )
-            data["response"] = response
-            logger.debug(data)
+            self.delete(module_id=module_id)
 
     def get_mod_type(self):
         data = {}
